Changes
=======

20200904 - 0.1.3
----------------

- Update auth handling
- Limit support because Home Assistant is pinning releases

20190609 - 0.1.2
----------------

- Improve quote handling
- Get all supported currencies

20190608 - 0.1.1
----------------

- Various fixes and improvements

20180819 - 0.1.0
----------------

- Initial release
